/*
 * time.h
 *
 * Copyright 2002, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 * time.cѥإåե
 */


#ifndef time_h
#define time_h


#include <sys/time.h>


#ifndef ASM_FILE


extern void initTime();
extern uint getNextIntervalTime(void);
extern uint calcCpuClock(void);
extern void calcUserTime();
extern void calcSysTime();
extern void setTime(uint);
extern void updateTime();
extern void gettimeofday(struct timeval*);
extern uint getMiliSecondsFromClock(uint64);
extern uint calcMiliSecondFromClock(uint64);
extern uint64 calcMicroSecondFromClock(uint64);
extern uint64 calcClockFromMicroSecond(uint64);
extern uint64 calcClockFromMiliSecond(uint64);
extern int sys_time();
extern int sys_settime(uint);
extern int sys_gettimeofday();
extern void initIntervalTimer();
extern int sysCalcMicroSeconds();


#endif


#endif
